==> PloneSubscription-1.0.tar.gz: PloneSubscription/content/SubscriptionProvider.py <==
# -*- coding: utf-8 -*-
"""
$Id: SubscriptionProvider.py,v 1.6 2005/09/22 12:56:30 encolpe Exp $
"""

__author__  = ''
__docformat__ = 'restructuredtext'


# Python imports
from AccessControl import ClassSecurityInfo

# Zope imports
from Acquisition import aq_base

# CMF imports
from Products.CMFCore  import CMFCorePermissions
from Products.CMFCore.utils import getToolByName

# Archetypes imports
from Products.Archetypes.public import *

# Products imports
from Products.PloneSubscription.config import PROJECTNAME, CATALOG_ID, CATALOG_INDEXES
from Products.PloneSubscription import SubscriptionPermissions
from Products.PloneSubscription.SubscriptionCatalog import SubscriptionCatalog, manage_addSubscriptionCatalog


schema = BaseBTreeFolderSchema.copy()

class SubscriptionProvider(BaseBTreeFolder):
    """Subscription Provider with BTree"""

    __implements__ = BaseBTreeFolder.__implements__

    portal_type = meta_type = 'SubscriptionProvider'
    archetype_name = 'SubscriptionProvider'
    immediate_view = 'base_view'
    default_view   = 'base_view'
    global_allow = True
    schema = schema
    allowed_content_types = ('UserSubscriber', 'GroupSubscriber')
    # XXX use property with Zope 2.8 and ZODB 3.4 only
    #allowed_content_types = property(getProviderAllowedContentTypes())
    include_default_actions = 0
    security = ClassSecurityInfo()

    actions = (
        {
        'id'            : 'view',
        'name'          : 'View',
        'action'        : 'string:${object_url}/base_view',
        'permissions'   : (SubscriptionPermissions.ManageSubscriptionContent, ),
        'category'      : 'object',
        'visible'       : 1,
        },
        {
        'id'            : 'edit',
        'name'          : 'Edit',
        'action'        : 'string:${object_url}/base_edit',
        'permissions'   : (SubscriptionPermissions.ManageSubscriptionContent, ),
        'category'      : 'object',
        'visible'       : 1,
        },
    )

    def __init__(self, id):
        """ install one catalog by provider """
        BaseBTreeFolder.__init__(self, id)

        add_catalog = manage_addSubscriptionCatalog
        add_catalog(self, SubscriptionCatalog.id, SubscriptionCatalog.title)
        catalog = getattr(aq_base(self), CATALOG_ID)
        catalog.manage_reindexIndex()

    security.declarePublic('getCatalog')
    def getCatalog(self):
        """Returns Subscription catalog"""
        return getattr(self, CATALOG_ID, None)

registerType(SubscriptionProvider, PROJECTNAME)

==> PloneSubscription-1.1.0.tar.gz: PloneSubscription/content/SubscriptionProvider.py <==
# -*- coding: utf-8 -*-
"""
$Id: SubscriptionProvider.py,v 1.9 2005/11/24 14:01:40 roeder Exp $
"""

__author__  = ''
__docformat__ = 'restructuredtext'


# Python imports
from AccessControl import ClassSecurityInfo

# Zope imports
from Acquisition import aq_base

# CMF imports
from Products.CMFCore  import CMFCorePermissions
from Products.CMFCore.utils import getToolByName

# Archetypes imports
from Products.Archetypes.public import *

# Products imports
from Products.PloneSubscription.config import PROJECTNAME, CATALOG_INDEXES
from Products.PloneSubscription import SubscriptionPermissions
from Products.PloneSubscription.SubscriptionCatalog import SubscriptionCatalog, manage_addSubscriptionCatalog


schema = BaseBTreeFolderSchema.copy()

class SubscriptionProvider(BaseBTreeFolder):
    """Subscription Provider with BTree"""

    __implements__ = BaseBTreeFolder.__implements__

    portal_type = meta_type = 'SubscriptionProvider'
    archetype_name = 'SubscriptionProvider'
    immediate_view = 'base_view'
    default_view   = 'base_view'
    global_allow = True
    schema = schema
    allowed_content_types = ('AnonymousSubscriber','UserSubscriber', 'GroupSubscriber')
    # XXX use property with Zope 2.8 and ZODB 3.4 only
    #allowed_content_types = property(getProviderAllowedContentTypes())
    include_default_actions = 0
    security = ClassSecurityInfo()

    actions = (
        {
        'id'            : 'view',
        'name'          : 'View',
        'action'        : 'string:${object_url}/base_view',
        'permissions'   : (SubscriptionPermissions.ManageSubscriptionContent, ),
        'category'      : 'object',
        'visible'       : 1,
        },
        {
        'id'            : 'edit',
        'name'          : 'Edit',
        'action'        : 'string:${object_url}/base_edit',
        'permissions'   : (SubscriptionPermissions.ManageSubscriptionContent, ),
        'category'      : 'object',
        'visible'       : 1,
        },
    )

registerType(SubscriptionProvider, PROJECTNAME)
